@@ -203,7 +203,7 @@ def multiline_prompt(
         event.app.exit(result=PromptCode.UNDO)
 
     # Trigger suggestions on backspace
-    # @kb.add("backspace")
+    @kb.add("backspace")
     def _(event: KeyPressEvent):
         """
         Trigger suggestions on backspace.
@@ -323,7 +323,7 @@ def chatcli(
         system: str = "You are a helpful assistant.",
         assistant: Optional[str] = None,
         swap_newline_keys: bool = False,
-        autosuggest: Literal["llm", "history", "none"] = "llm",
+        autosuggest: Literal["llm", "history", "none"] = "history",
 ) -> None:
     """
     Chat with an OpenAI API model using the command line.
@@ -335,6 +335,8 @@ def chatcli(
             The assistant message to send to the model.
         swap_newline_keys:
             Whether to swap the keys for submitting and entering a newline.
+        autosuggest:
+            The autosuggester to use.
     """
 
     # Print a header
